Index: src/iptc.cpp
===================================================================
--- src/iptc.cpp	(Revision 2475)
+++ src/iptc.cpp	(Arbeitskopie)
@@ -469,13 +469,29 @@
         return 0;
     } // IptcParser::decode
 
+    /*!
+      @brief Compare two iptc items by record. Return true if the record of
+             lhs is less than that of rhs.
+
+      This is a helper function for IptcParser::encode().
+     */
+    bool cmpIptcdataByRecord(const Iptcdatum& lhs, const Iptcdatum& rhs)
+    {
+        return lhs.record() < rhs.record();
+    }
+
     DataBuf IptcParser::encode(const IptcData& iptcData)
     {
         DataBuf buf(iptcData.size());
         byte *pWrite = buf.pData_;
 
-        IptcData::const_iterator iter = iptcData.begin();
-        IptcData::const_iterator end = iptcData.end();
+        // Copy the iptc data sets and sort them by record
+        IptcMetadata sortedIptcData;
+        std::copy(iptcData.begin(), iptcData.end(), std::back_inserter(sortedIptcData));
+        std::sort(sortedIptcData.begin(), sortedIptcData.end(), cmpIptcdataByRecord);
+
+        IptcData::const_iterator iter = sortedIptcData.begin();
+        IptcData::const_iterator end = sortedIptcData.end();
         for ( ; iter != end; ++iter) {
             // marker, record Id, dataset num
             *pWrite++ = marker_;
